@@ -20,7 +20,7 @@ while(<>)
    {
       my $key=$1;
       my $value=$2;
-      push(@hosts, split(/\s/, $value)) if($key eq "Site" || $key eq "Includes");
+      push(@hosts, split(/\s/, $value)) if($key eq "Site" || $key eq "Includes" || $key eq "Alias");
       push(@pathsdeb, $value) if($key eq $arkey);
    }
    elsif(@hosts)
