@@ -27,14 +27,14 @@ public:
 	 * 			filename w/o suffix or path prefix back into it
 	 * @param bCriticalOpen Terminate program on failure
 	 */ 
-	bool OpenFile(const mstring & sFilename, bool bNoMagic=false, uint nFakeTrailingNewlines=0);
+	bool OpenFile(const mstring & sFilename, bool bNoMagic=false, unsigned nFakeTrailingNewlines=0);
 	
 	//////! Filename with all prepended path and compressed suffix stripped
 	//////void GetBaseFileName(mstring & sOut);
 	//! Returns lines when beginning with non-space, otherwise empty string. 
 	//! @return False on errors.
 	bool GetOneLine(mstring & sOut, bool bForceUncompress=false);
-	uint GetCurrentLine() const { return m_nCurLine;} ;
+	unsigned GetCurrentLine() const { return m_nCurLine;} ;
 	bool CheckGoodState(bool bTerminateOnErrors, cmstring *reportFilePath=nullptr) const;
 	
 	bool GetChecksum(int csType, uint8_t out[], off_t &scannedSize, FILE *pDumpFile=nullptr);
@@ -63,7 +63,7 @@ private:
 	acbuf m_UncompBuf; // uncompressed window
 	
 	// visible position reporting
-	uint m_nCurLine;
+	unsigned m_nCurLine;
 	
 	int m_fd;
 	
