@@ -17,13 +17,6 @@
 #include <list>
 #include <unordered_map>
 
-#ifdef HAVE_SSL
-#include <openssl/evp.h>
-#include <openssl/bio.h>
-#include <openssl/sha.h>
-#include <openssl/crypto.h>
-#include <cstring>
-#endif
 
 using namespace std;
 
@@ -83,8 +76,8 @@ void AddRemapInfo(bool bAsBackend, const string & token, const string &repname);
 void AddRemapFlag(const string & token, const string &repname);
 void _AddHooksFile(cmstring& vname);
 
-uint ReadBackendsFile(const string & sFile, const string &sRepName);
-uint ReadRewriteFile(const string & sFile, cmstring& sRepName);
+unsigned ReadBackendsFile(const string & sFile, const string &sRepName);
+unsigned ReadRewriteFile(const string & sFile, cmstring& sRepName);
 
 map<cmstring, tRepoData> repoparms;
 typedef decltype(repoparms)::iterator tPairRepoNameData;
@@ -180,26 +173,26 @@ tProperty n2pTbl[] =
 		BARF("Invalid proxy specification, aborting...");
 	}
 	return true;
-}, [](bool superUser)
+}, [](bool superUser) -> string
 {
 	if(!superUser && !proxy_info.sUserPass.empty())
 		return string("#");
 	return proxy_info.sHost.empty() ? sEmptyString : proxy_info.ToURI(false);
 } },
-{ "LocalDirs", [](cmstring& key, cmstring& value)
+{ "LocalDirs", [](cmstring& key, cmstring& value) -> bool
 {
 	if(g_bNoComplex)
 	return true;
 	_ParseLocalDirs(value);
 	return !localdirs.empty();
-}, [](bool)
+}, [](bool) -> string
 {
 	string ret;
 	for(auto kv : localdirs)
 	ret += kv.first + " " + kv.second + "; ";
 	return ret;
 } },
-{ "Remap-", [](cmstring& key, cmstring& value)
+{ "Remap-", [](cmstring& key, cmstring& value) -> bool
 {
 	if(g_bNoComplex)
 	return true;
@@ -238,11 +231,11 @@ tProperty n2pTbl[] =
 		}
 		_AddHooksFile(vname);
 		return true;
-	}, [](bool)
+	}, [](bool) -> string
 	{
 		return "# mixed options";
 	} },
-{ "AllowUserPorts", [](cmstring& key, cmstring& value)
+{ "AllowUserPorts", [](cmstring& key, cmstring& value) -> bool
 {
 	if(!pUserPorts)
 	pUserPorts=new bitset<TCP_PORT_MAX>;
@@ -262,7 +255,7 @@ tProperty n2pTbl[] =
 		pUserPorts->set(n, true);
 	}
 	return true;
-}, [](bool)
+}, [](bool) -> string
 {
 	tSS ret;
 	if(pUserPorts)
@@ -272,7 +265,7 @@ tProperty n2pTbl[] =
 		}
 	return (string) ret;
 } },
-{ "ConnectProto", [](cmstring& key, cmstring& value)
+{ "ConnectProto", [](cmstring& key, cmstring& value) -> bool
 {
 	int *p = conprotos;
 	for (tSplitWalk split(&value); split.Next(); ++p)
@@ -292,19 +285,19 @@ tProperty n2pTbl[] =
 		BARF("IP protocol not supported: " << val);
 	}
 	return true;
-}, [](bool)
+}, [](bool) -> string
 {
 	string ret(conprotos[0] == PF_INET6 ? "v6" : "v4");
 	if(conprotos[0] != conprotos[1])
 		ret += string(" ") + (conprotos[1] == PF_INET6 ? "v6" : "v4");
 	return ret;
 } },
-{ "AdminAuth", [](cmstring& key, cmstring& value)
+{ "AdminAuth", [](cmstring& key, cmstring& value) -> bool
 {
 	adminauth=value;
 	adminauthB64=EncodeBase64Auth(value);
 	return true;
-}, [](bool)
+}, [](bool) -> string
 {
 	return "#"; // TOP SECRET";
 } }
@@ -537,8 +530,12 @@ tStrDeq ExpandFileTokens(cmstring &token)
 		return res; // errrr... done here
 	// merge them
 	tStrSet dupeFil;
-	for(const auto& s: res)
-		dupeFil.emplace(GetBaseName(s));
+        for(const auto& s: res)
+#ifdef COMPATGCC47
+           dupeFil.insert(GetBaseName(s));
+#else
+        dupeFil.emplace(GetBaseName(s));
+#endif
 	for(const auto& s: suppres)
 		if(!ContHas(dupeFil, GetBaseName(s)))
 			res.emplace_back(s);
@@ -564,7 +561,7 @@ inline void AddRemapInfo(bool bAsBackend, const string & token,
 	else
 	{
 		auto func = bAsBackend ? ReadBackendsFile : ReadRewriteFile;
-		uint count = 0;
+		unsigned count = 0;
 		for(auto& src : ExpandFileTokens(token))
 			count += func(src, repname);
 		if(!count)
@@ -636,7 +633,7 @@ inline void _AddHooksFile(cmstring& vname)
 		else if (strcasecmp("DownTimeout", p) == 0)
 		{
 			errno = 0;
-			uint n = strtoul(val.c_str(), nullptr, 10);
+			unsigned n = strtoul(val.c_str(), nullptr, 10);
 			if (!errno)
 				hs.downDuration = n;
 		}
@@ -716,7 +713,7 @@ cmstring & GetMimeType(cmstring &path)
 	if(f.OpenFile(path, true))
 	{
 		size_t maxLen = std::min(size_t(255), f.GetSize());
-		for(uint i=0; i< maxLen; ++i)
+		for(unsigned i=0; i< maxLen; ++i)
 		{
 			if(!isascii((uint) *(f.GetBuffer()+i)))
 				return os;
@@ -848,9 +845,9 @@ const tRepoData * GetRepoData(cmstring &vname)
 	return & it->second;
 }
 
-uint ReadBackendsFile(const string & sFile, const string &sRepName)
+unsigned ReadBackendsFile(const string & sFile, const string &sRepName)
 {
-	uint nAddCount=0;
+	unsigned nAddCount=0;
 	string key, val;
 	tHttpUrl entry;
 
@@ -908,9 +905,9 @@ void ShutDown()
 /* This parses also legacy files, i.e. raw RFC-822 formated mirror catalogue from the
  * Debian archive maintenance repository.
  */
-uint ReadRewriteFile(const string & sFile, cmstring& sRepName)
+unsigned ReadRewriteFile(const string & sFile, cmstring& sRepName)
 {
-	uint nAddCount=0;
+	unsigned nAddCount=0;
 	filereader reader;
 	if(debug>4)
 		cerr << "Reading rewrite file: " << sFile <<endl;
@@ -1033,7 +1030,7 @@ void ReadConfigDirectory(const char *szPath, bool bReadErrorIsFatal)
 	dump_proc_status();
 	if(debug & LOG_DEBUG)
 	{
-		uint nUrls=0;
+		unsigned nUrls=0;
 		for(const auto& x: mapUrl2pVname)
 			nUrls+=x.second.size();
 
@@ -1282,27 +1279,6 @@ time_t BackgroundCleanup()
 	return ret;
 }
 
-#ifdef SUPPWHASH
-#ifdef HAVE_SSL
-bool DecodeBase64(LPCSTR pAscii, acbuf& binData) {
-	if(!pAscii)
-		return false;
-	auto len=::strlen(pAscii);
-	binData.setsize(len);
-	binData.clear();
-	FILE* memStrm = ::fmemopen( (void*) pAscii, len, "r");
-	auto strmBase = BIO_new(BIO_f_base64());
-	auto strmBin = BIO_new_fp(memStrm, BIO_NOCLOSE);
-	strmBin = BIO_push(strmBase, strmBin);
-	BIO_set_flags(strmBin, BIO_FLAGS_BASE64_NO_NL);
-	binData.got(BIO_read(strmBin, binData.wptr(), len));
-	BIO_free_all(strmBin);
-	checkForceFclose(memStrm);
-	return binData.size();
-}
-#endif
-#endif
-
 lockable authLock;
 
 int CheckAdminAuth(LPCSTR auth)
@@ -1436,6 +1412,7 @@ bool CompileExpressions()
 			true : compat(rex[PASSTHROUGH].pat, connectPermPattern.c_str())));
 }
 
+// match the specified type by internal pattern PLUS the user-added pattern
 inline bool MatchType(cmstring &in, eMatchType type)
 {
 	if(rex[type].pat && !regexec(rex[type].pat, in.c_str(), 0, nullptr, 0))
@@ -1449,7 +1426,7 @@ bool Match(cmstring &in, eMatchType type)
 {
 	if(MatchType(in, type))
 		return true;
-	// XXX: very special behavior...
+	// very special behavior... for convenience
 	return (type == FILE_SOLID && MatchType(in, FILE_SPECIAL_SOLID))
 		|| (type == FILE_VOLATILE && MatchType(in, FILE_SPECIAL_VOLATILE));
 }
@@ -1475,7 +1452,7 @@ inline bool CompileUncachedRex(const string & token, NOCACHE_PATTYPE type, bool
 
 	if (0!=token.compare(0, 5, "file:")) // pure pattern
 	{
-		uint pos = patvec.size();
+		unsigned pos = patvec.size();
 		patvec.resize(pos+1);
 		return 0==regcomp(&patvec[pos], token.c_str(), REG_EXTENDED);
 	}
@@ -1543,7 +1520,7 @@ void mkbasedir(const string & path)
 	if(0==mkdir(GetDirPart(path).c_str(), acfg::dirperms) || EEXIST == errno)
 		return; // should succeed in most cases
 
-	uint pos=0; // but skip the cache dir components, if possible
+	unsigned pos=0; // but skip the cache dir components, if possible
 	if(startsWith(path, acfg::cacheDirSlash))
 	{
 		// pos=acfg::cachedir.size();
