@@ -91,7 +91,7 @@ inline static void RedirectBto2https(int fdClient, cmstring& uri)
 }
 void PassThrough(acbuf &clientBufIn, int fdClient, cmstring& uri)
 {
-	tTcpHandlePtr m_spOutCon;
+	tDlStreamHandle m_spOutCon;
 
 	string sErr;
 	tSS clientBufOut;
@@ -101,25 +101,34 @@ void PassThrough(acbuf &clientBufIn, int fdClient, cmstring& uri)
 	tHttpUrl url;
 	if (!url.SetHttpUrl(uri))
 		return;
-	if (acfg::proxy_info.sHost.empty())
+	auto proxy = acfg::GetProxyInfo();
+	if (!proxy)
 	{
-		m_spOutCon = tcpconnect::CreateConnected(url.sHost, url.GetPort(), sErr, 0, 0,
+		direct_connect:
+		m_spOutCon = g_tcp_con_factory.CreateConnected(url.sHost, url.GetPort(), sErr, 0, 0,
 		false, acfg::nettimeout, true);
 	}
 	else
 	{
 		// switch to HTTPS tunnel in order to get a direct connection through the proxy
-		m_spOutCon = tcpconnect::CreateConnected(acfg::proxy_info.sHost, acfg::proxy_info.GetPort(),
-				sErr, 0, 0, false, acfg::nettimeout, true);
+		m_spOutCon = g_tcp_con_factory.CreateConnected(proxy->sHost, proxy->GetPort(),
+				sErr, 0, 0, false, acfg::optproxytimeout > 0 ?
+						acfg::optproxytimeout : acfg::nettimeout,
+						true);
 
 		if (m_spOutCon)
 		{
 			if (!m_spOutCon->StartTunnel(tHttpUrl(url.sHost, url.GetPort(),
-			true), sErr, &acfg::proxy_info.sUserPass, false))
+			true), sErr, & proxy->sUserPass, false))
 			{
 				m_spOutCon.reset();
 			}
 		}
+		else if(acfg::optproxytimeout > 0) // ok... try without
+		{
+			acfg::MarkProxyFailure();
+			goto direct_connect;
+		}
 	}
 
 	if (m_spOutCon)
